/**
 * WIP Logging abstraction
 */
import { Consola, ConsolaOptions } from 'consola';
export { LogLevel } from 'consola';
export interface LoggerOptions extends ConsolaOptions {
}
export interface Logger extends Consola {
    /**
     * A logger method for deprecated symbols.
     *
     * @remarks
     * Pair with a deprecated tag. See {@link https://tsdoc.org/pages/tags/deprecated/} for more information.
     *
     * @example
     * ```ts
     * logger.deprecated('someSymbol');
     * ```
     *
     * @example With a custom instruction and target removal version.
     * ```ts
     * logger.deprecated('routeButtons', 'Use the default slot instead.', '20.0.0');
     * ```
     *
     * @param symbol - The deprecated symbol.
     * @param instruction - An optional alternative instruction. Defaults to `Consult docs for better alternative.`
     * @param removalVersionTarget - An optional target removal version number.
     */
    deprecated(symbol: string, instruction?: string, removalVersionTarget?: string): void;
}
export declare const defaultLoggerOptions: LoggerOptions;
export declare function createLogger(name: string, options?: LoggerOptions): Logger;
//# sourceMappingURL=logger.d.ts.map